mailr26034 - /branches/frame_order_cleanup/auto_analyses/frame_order.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on September 25, 2014 - 11:20:
Author: bugman
Date: Thu Sep 25 11:20:25 2014
New Revision: 26034

URL: http://svn.gna.org/viewcvs/relax?rev=26034&view=rev
Log:
Fixes for the auto_analyses.frame_order.summerise() function.

If the count_sobol_points() function is called followed by summerise(), a 
RelaxError will be raised
as the data pipe already exists.  The summerise() function has been modified 
to switch to the data
pipe if it already exists.


Modified:
    branches/frame_order_cleanup/auto_analyses/frame_order.py

Modified: branches/frame_order_cleanup/auto_analyses/frame_order.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_cleanup/auto_analyses/frame_order.py?rev=26034&r1=26033&r2=26034&view=diff
==============================================================================
--- branches/frame_order_cleanup/auto_analyses/frame_order.py   (original)
+++ branches/frame_order_cleanup/auto_analyses/frame_order.py   Thu Sep 25 
11:20:25 2014
@@ -254,11 +254,17 @@
         if not access(dirs[i]+sep+'results.bz2', F_OK):
             continue
 
-        # Create a data pipe.
-        pipes.create(models[i], 'frame order')
-
-        # Load the data.
-        results.read(file='results', dir=dirs[i])
+        # Switch to the data pipe if it already exists.
+        if pipes.has_pipe(models[i]):
+            pipes.switch(models[i])
+
+        # Otherwise load the data.
+        else:
+            # Create a data pipe.
+            pipes.create(models[i], 'frame order')
+
+            # Load the data.
+            results.read(file='results', dir=dirs[i])
 
         # Number of params.
         k = len(cdp.params)




Related Messages


Powered by MHonArc, Updated Thu Sep 25 11:40:02 2014